@@ -1,5 +1,5 @@
 package JSON::Karabiner ;
-$JSON::Karabiner::VERSION = '0.013';
+$JSON::Karabiner::VERSION = '0.014';
 use strict;
 use warnings;
 use JSON;
@@ -65,10 +65,11 @@ sub write_file {
         push @main::saved_manips, @{$manip};
       }
     }
+    use Data::Dumper qw(Dumper);
+    print Dumper $s->{_karabiner}->{rules}[0];
 
-    @{$s->{_karabiner}->{rules}} = @main::saved_manips;
+    @{$s->{_karabiner}->{rules}[0]{manipulators}} = @main::saved_manips;
   }
-
   my $json = $s->_get_json();
 
   #TODO ensure it works with utf8
@@ -590,7 +591,7 @@ modules|https://www.cpan.org/modules/INSTALL.html> for more information.
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 Development Status
 
